@@ -21,6 +21,7 @@ from signac.common import config
 
 from .directives import (
     _GET_EXECUTABLE,
+    _MEMORY,
     _NGPU,
     _NP,
     _NRANKS,
@@ -224,7 +225,12 @@ class ComputeEnvironment(metaclass=_ComputeEnvironmentType):
             The argument parser where arguments will be added.
 
         """
-        return
+        parser.add_argument(
+            "-w",
+            "--walltime",
+            type=float,
+            help="The wallclock time in hours. Deprecated in 0.13 and will be removed in 0.14.",
+        )
 
     @classmethod
     def get_config_value(cls, key, default=flow_config._GET_CONFIG_VALUE_NONE):
@@ -354,6 +360,7 @@ class ComputeEnvironment(metaclass=_ComputeEnvironmentType):
                 _GET_EXECUTABLE(),
                 _WALLTIME,
                 _PROCESSOR_FRACTION,
+                _MEMORY,
             ]
         )
 
@@ -432,9 +439,6 @@ class DefaultTorqueEnvironment(NodesEnvironment, TorqueEnvironment):
 
         """
         super().add_args(parser)
-        parser.add_argument(
-            "-w", "--walltime", type=float, help="The wallclock time in hours."
-        )
         parser.add_argument(
             "--hold", action="store_true", help="Submit jobs, but put them on hold."
         )
@@ -465,20 +469,6 @@ class DefaultSlurmEnvironment(NodesEnvironment, SlurmEnvironment):
 
         """
         super().add_args(parser)
-        parser.add_argument(
-            "--memory",
-            help=(
-                'Specify how much memory to reserve per node, e.g. "4g" for 4 gigabytes '
-                'or "512m" for 512 megabytes. Only relevant for shared queue jobs.'
-            ),
-        )
-        parser.add_argument(
-            "-w",
-            "--walltime",
-            type=float,
-            default=12,
-            help="The wallclock time in hours.",
-        )
         parser.add_argument(
             "--hold", action="store_true", help="Submit jobs, but put them on hold."
         )
@@ -504,13 +494,6 @@ class DefaultLSFEnvironment(NodesEnvironment, LSFEnvironment):
 
         """
         super().add_args(parser)
-        parser.add_argument(
-            "-w",
-            "--walltime",
-            type=float,
-            default=12,
-            help="The wallclock time in hours.",
-        )
         parser.add_argument(
             "--hold", action="store_true", help="Submit jobs, but put them on hold."
         )
